# AYCD AutoSolve Python Client

Client for connecting to the AYCD AutoSolve network

## Documentation

https://docs.aycd.io/docs/getting-started/


## License

This project is licensed under the MIT License
